@@ -1,12 +1,16 @@
+import os
 from typing import Any, Dict, List, Optional, Tuple, Union
 
+from multimethod import multimethod
 from pandas.core.frame import DataFrame
 from pandas.core.series import Series
 
+from ..caller_base import CallerBase
 from ..error.client_only_endpoint import client_only_endpoint
 from ..error.illegal_attr_checker import IllegalAttrChecker
 from ..error.uncallable_namespace import UncallableNamespace
-from ..query_runner.query_runner import QueryRunner
+from ..server_version.compatible_with import compatible_with
+from ..server_version.server_version import ServerVersion
 from .graph_export_runner import GraphExportRunner
 from .graph_object import Graph
 from .graph_project_runner import GraphProjectRunner
@@ -14,20 +18,16 @@ from .graph_project_runner import GraphProjectRunner
 Strings = Union[str, List[str]]
 
 
-class GraphProcRunner(UncallableNamespace, IllegalAttrChecker):
-    def __init__(self, query_runner: QueryRunner, namespace: str):
-        self._query_runner = query_runner
-        self._namespace = namespace
-
+class GraphProcRunner(CallerBase, UncallableNamespace, IllegalAttrChecker):
     @property
     def project(self) -> GraphProjectRunner:
         self._namespace += ".project"
-        return GraphProjectRunner(self._query_runner, self._namespace)
+        return GraphProjectRunner(self._query_runner, self._namespace, self._server_version)
 
     @property
     def export(self) -> GraphExportRunner:
         self._namespace += ".export"
-        return GraphExportRunner(self._query_runner, self._namespace)
+        return GraphExportRunner(self._query_runner, self._namespace, self._server_version)
 
     def drop(
         self,
@@ -76,9 +76,11 @@ class GraphProcRunner(UncallableNamespace, IllegalAttrChecker):
     @client_only_endpoint("gds.graph")
     def get(self, graph_name: str) -> Graph:
         if not self.exists(graph_name)["exists"]:
-            raise ValueError(f"No projected graph named '{graph_name}' exists")
+            raise ValueError(
+                f"No projected graph named '{graph_name}' exists in current database '{self._query_runner.database()}'"
+            )
 
-        return Graph(graph_name, self._query_runner)
+        return Graph(graph_name, self._query_runner, self._server_version)
 
     def _handle_properties(
         self,
@@ -102,11 +104,25 @@ class GraphProcRunner(UncallableNamespace, IllegalAttrChecker):
         G: Graph,
         node_properties: List[str],
         node_labels: Strings = ["*"],
+        separate_property_columns: bool = False,
         **config: Any,
     ) -> DataFrame:
         self._namespace += ".streamNodeProperties"
 
-        return self._handle_properties(G, node_properties, node_labels, config)
+        result = self._handle_properties(G, node_properties, node_labels, config)
+
+        # new format was requested, but the query was run via Cypher
+        if separate_property_columns and "propertyValue" in result.keys():
+            result = result.pivot(index="nodeId", columns="nodeProperty", values="propertyValue")
+            result = result.reset_index()
+            result.columns.name = None
+        # old format was requested but the query was run via Arrow
+        elif not separate_property_columns and "propertyValue" not in result.keys():
+            result = result.melt(id_vars=["nodeId"]).rename(
+                columns={"variable": "nodeProperty", "value": "propertyValue"}
+            )
+
+        return result
 
     def streamNodeProperty(
         self,
@@ -124,11 +140,29 @@ class GraphProcRunner(UncallableNamespace, IllegalAttrChecker):
         G: Graph,
         relationship_properties: List[str],
         relationship_types: Strings = ["*"],
+        separate_property_columns: bool = False,
         **config: Any,
     ) -> DataFrame:
         self._namespace += ".streamRelationshipProperties"
 
-        return self._handle_properties(G, relationship_properties, relationship_types, config)
+        result = self._handle_properties(G, relationship_properties, relationship_types, config)
+
+        # new format was requested, but the query was run via Cypher
+        if separate_property_columns and "propertyValue" in result.keys():
+            result = result.pivot(
+                index=["sourceNodeId", "targetNodeId", "relationshipType"],
+                columns="relationshipProperty",
+                values="propertyValue",
+            )
+            result = result.reset_index()
+            result.columns.name = None
+        # old format was requested but the query was run via Arrow
+        elif not separate_property_columns and "propertyValue" not in result.keys():
+            result = result.melt(id_vars=["sourceNodeId", "targetNodeId", "relationshipType"]).rename(
+                columns={"variable": "relationshipProperty", "value": "propertyValue"}
+            )
+
+        return result
 
     def streamRelationshipProperty(
         self,
@@ -171,11 +205,35 @@ class GraphProcRunner(UncallableNamespace, IllegalAttrChecker):
 
         return self._query_runner.run_query(query, params).squeeze()  # type: ignore
 
-    def removeNodeProperties(
+    @multimethod
+    def removeNodeProperties(self) -> None:
+        ...
+
+    @removeNodeProperties.register
+    def _(
         self,
         G: Graph,
         node_properties: List[str],
-        node_labels: Strings = ["*"],
+        **config: Any,
+    ) -> Series:
+        self._namespace += ".removeNodeProperties"
+
+        query = f"CALL {self._namespace}($graph_name, $properties, $config)"
+        params = {
+            "graph_name": G.name(),
+            "properties": node_properties,
+            "config": config,
+        }
+
+        return self._query_runner.run_query(query, params).squeeze()  # type: ignore
+
+    @removeNodeProperties.register
+    @compatible_with("removeNodeProperties", max_exclusive=ServerVersion(2, 1, 0))
+    def _(
+        self,
+        G: Graph,
+        node_properties: List[str],
+        node_labels: Strings,
         **config: Any,
     ) -> Series:
         self._namespace += ".removeNodeProperties"
@@ -206,4 +264,34 @@ class GraphProcRunner(UncallableNamespace, IllegalAttrChecker):
 
         result = self._query_runner.run_query(query, params).squeeze()
 
-        return Graph(graph_name, self._query_runner), result
+        return Graph(graph_name, self._query_runner, self._server_version), result
+
+    @client_only_endpoint("gds.alpha.graph")
+    @compatible_with("construct", min_inclusive=ServerVersion(2, 1, 0))
+    def construct(
+        self,
+        graph_name: str,
+        nodes: Union[DataFrame, List[DataFrame]],
+        relationships: Union[DataFrame, List[DataFrame]],
+        concurrency: int = 4,
+    ) -> Graph:
+        nodes = nodes if isinstance(nodes, List) else [nodes]
+        relationships = relationships if isinstance(relationships, List) else [relationships]
+
+        errors = []
+        for idx, node_df in enumerate(nodes):
+            if "nodeId" not in node_df.columns.values:
+                errors.append(f"Node dataframe at index {idx} needs to contain a 'nodeId' column.")
+
+        for idx, rel_df in enumerate(relationships):
+            for expected_col in ["sourceNodeId", "targetNodeId"]:
+                if expected_col not in rel_df.columns.values:
+                    errors.append(f"Relationship dataframe at index {idx} needs to contain a '{expected_col}' column.")
+
+        if len(errors) > 0:
+            raise ValueError(os.linesep.join(errors))
+
+        constructor = self._query_runner.create_graph_constructor(graph_name, concurrency)
+        constructor.run(nodes, relationships)
+
+        return Graph(graph_name, self._query_runner, self._server_version)
