@@ -6,10 +6,10 @@ from pandas.core.series import Series
 
 from ..model.link_prediction_model import LPModel
 from ..query_runner.query_runner import QueryRunner
-from .training_pipeline import TrainingPipeline
+from .classification_training_pipeline import ClassificationTrainingPipeline
 
 
-class LPTrainingPipeline(TrainingPipeline):
+class LPTrainingPipeline(ClassificationTrainingPipeline):
     def addFeature(self, feature_type: str, **config: Any) -> Series:
         query = f"{self._query_prefix()}addFeature($pipeline_name, $feature_type, $config)"
         params = {
@@ -28,4 +28,4 @@ class LPTrainingPipeline(TrainingPipeline):
         return "CALL gds.beta.pipeline.linkPrediction."
 
     def _create_trained_model(self, name: str, query_runner: QueryRunner) -> LPModel:
-        return LPModel(name, query_runner)
+        return LPModel(name, query_runner, self._server_version)
