@@ -2,17 +2,13 @@ from typing import Tuple
 
 from pandas.core.series import Series
 
+from ..caller_base import CallerBase
 from ..error.illegal_attr_checker import IllegalAttrChecker
 from ..error.uncallable_namespace import UncallableNamespace
-from ..query_runner.query_runner import QueryRunner
 from .nc_training_pipeline import NCTrainingPipeline
 
 
-class NCPipelineCreateRunner(UncallableNamespace, IllegalAttrChecker):
-    def __init__(self, query_runner: QueryRunner, namespace: str):
-        self._query_runner = query_runner
-        self._namespace = namespace
-
+class NCPipelineCreateRunner(CallerBase, UncallableNamespace, IllegalAttrChecker):
     def create(self, name: str) -> Tuple[NCTrainingPipeline, Series]:
         self._namespace += ".create"
 
@@ -20,4 +16,4 @@ class NCPipelineCreateRunner(UncallableNamespace, IllegalAttrChecker):
         params = {"name": name}
         result = self._query_runner.run_query(query, params).squeeze()
 
-        return NCTrainingPipeline(name, self._query_runner), result
+        return NCTrainingPipeline(name, self._query_runner, self._server_version), result
